# Change Log

## [0.2.0] - 2021-01-03

### Added

- Added sus generator.
- Exported ``Score``, ``Metadata``, and ``Note`` class.

### Fixed

- Fixed tick is not int.

## [0.1.1] - 2021-01-03

### Fixed

- Fixed not returning in ``sus.load()`` resulting in None output.

## [0.1.0] - 2022-01-02

### Added

- Initialized Project.
- Added sus parser.
